@@ -39,6 +39,7 @@
 #endif
 
 #include <stddef.h>
+#include <stdint.h>
 #include <stdio.h>
 #include <ctype.h>
 #ifdef HAVE_ST_H
@@ -99,10 +100,10 @@ extern "C" {
  * Node definitions
  */
 #ifndef ST_DATA_T_DEFINED
-typedef long st_data_t;
+typedef uintptr_t st_data_t;
 #endif
 
-#define SYMID unsigned long
+#define SYMID uintptr_t
 
 typedef struct _syck_node SyckNode;
 
@@ -391,6 +392,7 @@ char *syck_match_implicit( char *, size_t );
  * API prototypes
  */
 char *syck_strndup( char *, long );
+int syck_str_is_unquotable_integer(char*, long);
 long syck_io_file_read( char *, SyckIoFile *, long, long );
 long syck_io_str_read( char *, SyckIoStr *, long, long );
 char *syck_base64enc( char *, long );
@@ -403,7 +405,7 @@ void syck_emitter_handler( SyckEmitter *, SyckEmitterHandler );
 void syck_free_emitter( SyckEmitter * );
 void syck_emitter_clear( SyckEmitter * );
 void syck_emitter_write( SyckEmitter *, const char *, long );
-void syck_emitter_escape( SyckEmitter *, char *, long );
+void syck_emitter_escape( SyckEmitter *, unsigned char *, long );
 void syck_emitter_flush( SyckEmitter *, long );
 void syck_emit( SyckEmitter *, st_data_t );
 void syck_emit_scalar( SyckEmitter *, char *, enum scalar_style, int, int, char, char *, long );
